pub enum Commands {
Show 19 variants
Show {
id: u32,
follow: bool,
body: bool,
},
List {
type: Option<String>,
grep: Option<String>,
case_sensitive: bool,
exact_match: bool,
regex_mode: bool,
},
Refs {
id: u32,
follow: bool,
},
Links {
id: u32,
follow: bool,
},
Search {
query: String,
case_sensitive: bool,
exact_match: bool,
regex_mode: bool,
follow: bool,
},
Add {
type: Option<String>,
title: Option<String>,
body: Option<String>,
strict: bool,
},
Deprecate {
id: u32,
to: u32,
},
Edit {
id: u32,
},
Patch {
id: u32,
type: Option<String>,
title: Option<String>,
body: Option<String>,
strict: bool,
},
Put {
id: u32,
line: String,
strict: bool,
},
Verify {
id: u32,
},
Delete {
id: u32,
force: bool,
},
Lint {
fix: bool,
},
Orphans {
with_descriptions: bool,
},
Type {
of: Option<String>,
},
Relationships {
id: u32,
follow: bool,
},
Graph {
id: u32,
follow: bool,
},
Prime,
Batch {
input: Option<PathBuf>,
format: String,
dry_run: bool,
fix: bool,
},
}Variants
Show
Show a node by ID (displays incoming and outgoing references)
Fields
List
List nodes (optionally filtered by –type or –grep with search flags)
Fields
Refs
Show nodes that REFERENCE (← INCOMING) the given ID
Fields
Links
Show nodes that the given ID REFERENCES (→ OUTGOING)
Fields
Search
Search nodes by substring (case-insensitive, alias: mindmap-cli search = mindmap-cli list –grep) Search nodes by substring (case-insensitive by default, use flags for advanced search)
Fields
Add
Add a new node
Fields
Deprecate
Deprecate a node, redirecting to another
Edit
Edit a node with $EDITOR
Patch
Patch (partial update) a node: –type, –title, –body
Put
Put (full-line replace) a node: –line
Verify
Mark a node as needing verification (append verify tag)
Delete
Delete a node by ID; use –force to remove even if referenced
Lint
Lint the mindmap for basic issues (use –fix to auto-fix spacing and type prefixes)
Orphans
Show orphan nodes (no in & no out, excluding META)
Type
Show all node types in use with statistics and frequency
Relationships
Show incoming and outgoing references for a node in one view
Fields
Graph
Show graph neighborhood for a node (DOT format for Graphviz)
Prime
Prime: print help and list to prime an AI agent’s context
Batch
Batch mode: apply multiple non-interactive commands atomically